# 🧊 `stpyvista`

### Show PyVista visualizations in Streamlit

This component takes a PyVista plotter object and shows it on Streamlit as an interactive element (as in it can be zoomed in/out, moved and rotated, but the visualization state is not returned). It uses [Panel](https://panel.holoviz.org/reference/panes/VTK.html#working-with-pyvista) to render PyVista plotter objects within an iframe.

****

### 📦 Installation

```sh
pip install stpyvista
```
****
### 📚 Demo and documentation 

[https://stpyvista.streamlit.app](https://stpyvista.streamlit.app)

****
### 🛠️ Source code

[https://github.com/edsaac/stpyvista](https://github.com/edsaac/stpyvista)
